# pyheaven

**Warning: This package is currently underdeveloped and does not guarantee any consistency.**

## Package Introduction

This is a package that contains useful functions for python programming as well as daily lives.

## Package Docs

[HTML Docs](https://htmlpreview.github.io/?https://github.com/Magolor/pyheaven/blob/master/doc/pyheaven.html)